@@ -24,7 +24,8 @@ test_equal(sha3(NULL), "b3e37e4c5def1bfb2841b79ef8503b83d1fed46836b5b913d7c16de9
 test_equal(sha3(substitute()), "9d31eb41cfb721b8040c52d574df1aacfc381d371c2b933f90792beba5160a57")
 # Error handling tests:
 test_error(sha3("secret base", bits = 6), "'bits' must be 224, 256, 384 or 512")
-test_error(sha3(file = NULL), "'file' must be specified as a character string")
+test_error(sha3("", convert = 1), "'convert' must be a logical value")
+test_error(sha3(file = NULL), "'file' must be a character string")
 # File interface tests:
 hash_func <- function(file, string) {
   on.exit(unlink(file))
@@ -74,7 +75,8 @@ test_equal(sha256(`attr<-`("base", "secret", "base")), "6e9e5b1a42304047ba731613
 test_equal(sha256(NULL), "71557d1c8bac9bbe3cbec8d00bb223a2f372279827064095447e569fbf5a760a")
 test_equal(sha256(substitute()), "4627dde6550f3e355515de5f2c6bb0099161c53c2c7186ce79ab1a74df004bfc")
 test_equal(sha256(`class<-`(sha256(character(), convert = FALSE), "hash")), "c762db048ff48f7ba3e9df5539db3aa678cb2f336d96d5c81b4e5d3e19783d14") 
-test_error(sha256(file = NULL), "'file' must be specified as a character string")
+test_error(sha256("", convert = 0), "'convert' must be a logical value")
+test_error(sha256(file = NULL), "'file' must be a character string")
 hash_func <- function(file, string) {
   on.exit(unlink(file))
   cat(string, file = file)
@@ -106,8 +108,9 @@ test_equal(siphash13(c("secret", "base")), "ddf3c7a54c52150c")
 test_equal(siphash13(`attr<-`("base", "secret", "base")), "4a7c3eb69f91f04e")
 test_equal(siphash13(NULL), "08d5f59e833de599")
 test_equal(siphash13(substitute()), "c8cadc1ab377142a")
-test_equal(siphash13(`class<-`(siphash13(character(), convert = FALSE), "hash")), "39124d8b9643418a") 
-test_error(siphash13(file = NULL), "'file' must be specified as a character string")
+test_equal(siphash13(`class<-`(siphash13(character(), convert = FALSE), "hash")), "39124d8b9643418a")
+test_error(siphash13("", convert = 0L), "'convert' must be a logical value")
+test_error(siphash13(file = NULL), "'file' must be a character string")
 hash_func <- function(file, string) {
   on.exit(unlink(file))
   cat(string, file = file)
@@ -123,6 +126,8 @@ test_that(base64enc(data.frame(), convert = FALSE), is.raw)
 test_that(base64dec(base64enc(as.raw(c(1L, 2L)), convert = FALSE), convert = FALSE), is.raw)
 test_that(base64dec(base64enc(c(1L, 2L)), convert = NA), is.integer)
 test_that(base64dec(base64enc(data.frame())), is.raw)
+test_error(base64enc("", convert = 0), "'convert' must be a logical value")
+test_error(base64dec("", convert = 1L), "'convert' must be a logical value")
 test_error(base64dec("__"), "input is not valid base64")
 test_error(base64dec(404), "input is not valid base64")
 test_error(base64dec("c2Vjcm V0IGJhc2U="), "input is not valid base64")
